darkhistory.physics.alpha_recomb — DarkHistory documentation

# darkhistory.physics.alpha_recomb

`darkhistory.physics.` `alpha_recomb`(T_m, species)

  Case-B recombination coefficient.

  Parameters: | T_m : float The matter temperature. species : {‘HI’, ‘HeI_21s’, ‘HeI_23s’} The species of interest.
  Returns: | float Case-B recombination coefficient in cm-3s-1.

  Notes

  For HeI, returns beta with respect to the 2s state, in agreement with convention in RECFAST.

#### Previous topic

darkhistory.physics.width_21s_1s_He

#### Next topic

darkhistory.physics.beta_ion

### This Page

Show Source